"use strict";

exports.__esModule = true;
exports.NumberIncrementStepper = exports.NumberDecrementStepper = exports.StyledStepper = exports.NumberInputField = exports.NumberInputStepper = exports.NumberInput = void 0;

var _chakraUiSystem = require("@hackr/chakra-ui-system");

var _chakraUiUtils = require("@hackr/chakra-ui-utils");

var React = _interopRequireWildcard(require("react"));

var _icons = require("./icons");

var _useNumberInput2 = require("./use-number-input");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * React context used to communicate between components
 */
var _createContext = (0, _chakraUiUtils.createContext)({
  name: "NumberInputContext",
  errorMessage: "useNumberInputContext: `context` is undefined. Seems you forgot to wrap number-input's components within <NumberInput />"
}),
    NumberInputProvider = _createContext[0],
    useNumberInputContext = _createContext[1];

/**
 * NumberInput
 *
 * React component that provides context and logic to all
 * number input sub-components.
 *
 * It renders a `div` by default.
 *
 * @see Docs http://chakra-ui.com/numberinput
 */
var NumberInput = /*#__PURE__*/(0, _chakraUiSystem.forwardRef)(function NumberInput(props, ref) {
  var styles = (0, _chakraUiSystem.useMultiStyleConfig)("NumberInput", props);
  var ownProps = (0, _chakraUiSystem.omitThemingProps)(props);

  var _useNumberInput = (0, _useNumberInput2.useNumberInput)(ownProps),
      htmlProps = _useNumberInput.htmlProps,
      context = _objectWithoutPropertiesLoose(_useNumberInput, ["htmlProps"]);

  var ctx = React.useMemo(function () {
    return context;
  }, [context]);
  return /*#__PURE__*/React.createElement(NumberInputProvider, {
    value: ctx
  }, /*#__PURE__*/React.createElement(_chakraUiSystem.StylesProvider, {
    value: styles
  }, /*#__PURE__*/React.createElement(_chakraUiSystem.chakra.div, _extends({
    ref: ref
  }, htmlProps, {
    __css: {
      position: "relative",
      zIndex: 0
    }
  }))));
});
exports.NumberInput = NumberInput;

if (_chakraUiUtils.__DEV__) {
  NumberInput.displayName = "NumberInput";
}

/**
 * NumberInputStepper
 *
 * React component used to group the increment and decrement
 * button spinners.
 *
 * It renders a `div` by default.
 *
 * @see Docs http://chakra-ui.com/components/number-input
 */
var NumberInputStepper = /*#__PURE__*/(0, _chakraUiSystem.forwardRef)(function NumberInputStepper(props, ref) {
  var styles = (0, _chakraUiSystem.useStyles)();
  return /*#__PURE__*/React.createElement(_chakraUiSystem.chakra.div, _extends({
    "aria-hidden": true,
    ref: ref
  }, props, {
    __css: _extends({
      display: "flex",
      flexDirection: "column",
      position: "absolute",
      top: "0",
      right: "0px",
      margin: "1px",
      height: "calc(100% - 2px)",
      zIndex: 1
    }, styles.stepperGroup)
  }));
});
exports.NumberInputStepper = NumberInputStepper;

if (_chakraUiUtils.__DEV__) {
  NumberInputStepper.displayName = "NumberInputStepper";
}

/**
 * NumberInputField
 *
 * React component that represents the actual `input` field
 * where users can type to edit numeric values.
 *
 * It renders an `input` by default and ensures only numeric
 * values can be typed.
 *
 * @see Docs http://chakra-ui.com/numberinput
 */
var NumberInputField = /*#__PURE__*/(0, _chakraUiSystem.forwardRef)(function NumberInputField(props, ref) {
  var _useNumberInputContex = useNumberInputContext(),
      getInputProps = _useNumberInputContex.getInputProps;

  var input = getInputProps(props, ref);
  var styles = (0, _chakraUiSystem.useStyles)();
  return /*#__PURE__*/React.createElement(_chakraUiSystem.chakra.input, _extends({}, input, {
    __css: _extends({
      width: "100%"
    }, styles.field)
  }));
});
exports.NumberInputField = NumberInputField;

if (_chakraUiUtils.__DEV__) {
  NumberInputField.displayName = "NumberInputField";
}

var StyledStepper = (0, _chakraUiSystem.chakra)("div", {
  baseStyle: {
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
    flex: 1,
    transition: "all 0.3s",
    userSelect: "none",
    cursor: "pointer",
    lineHeight: "normal"
  }
});
exports.StyledStepper = StyledStepper;

/**
 * NumberDecrementStepper
 *
 * React component used to decrement the number input's value
 *
 * It renders a `div` with `role=button` by default
 */
var NumberDecrementStepper = /*#__PURE__*/(0, _chakraUiSystem.forwardRef)(function NumberDecrementStepper(props, ref) {
  var _props$children;

  var styles = (0, _chakraUiSystem.useStyles)();

  var _useNumberInputContex2 = useNumberInputContext(),
      getDecrementButtonProps = _useNumberInputContex2.getDecrementButtonProps;

  var decrement = getDecrementButtonProps(props, ref);
  return /*#__PURE__*/React.createElement(StyledStepper, _extends({}, decrement, {
    __css: styles.stepper
  }), (_props$children = props.children) != null ? _props$children : /*#__PURE__*/React.createElement(_icons.TriangleDownIcon, null));
});
exports.NumberDecrementStepper = NumberDecrementStepper;

if (_chakraUiUtils.__DEV__) {
  NumberDecrementStepper.displayName = "NumberDecrementStepper";
}

/**
 * NumberIncrementStepper
 *
 * React component used to increment the number input's value
 *
 * It renders a `div` with `role=button` by default
 */
var NumberIncrementStepper = /*#__PURE__*/(0, _chakraUiSystem.forwardRef)(function NumberIncrementStepper(props, ref) {
  var _props$children2;

  var _useNumberInputContex3 = useNumberInputContext(),
      getIncrementButtonProps = _useNumberInputContex3.getIncrementButtonProps;

  var increment = getIncrementButtonProps(props, ref);
  var styles = (0, _chakraUiSystem.useStyles)();
  return /*#__PURE__*/React.createElement(StyledStepper, _extends({}, increment, {
    __css: styles.stepper
  }), (_props$children2 = props.children) != null ? _props$children2 : /*#__PURE__*/React.createElement(_icons.TriangleUpIcon, null));
});
exports.NumberIncrementStepper = NumberIncrementStepper;

if (_chakraUiUtils.__DEV__) {
  NumberIncrementStepper.displayName = "NumberIncrementStepper";
}
//# sourceMappingURL=number-input.js.map